@@ -13,6 +13,7 @@
 #    * See the License for the specific language governing permissions and
 #    * limitations under the License.
 
+from . import models
 from cloudify_common_sdk.clean_json import JsonCleanuper
 
 
@@ -34,3 +35,16 @@ class Resource(object):
         # TODO: I would like to have analysis per type,
         # but this honestly works OK.
         return JsonCleanuper(self.resource).to_dict()
+
+    @property
+    def model(self):
+        status_obj_name = 'Kubernetes{0}Status'.format(self.state.get('kind'))
+        return getattr(models,
+                       status_obj_name,
+                       getattr(models.KubernetesResourceStatus))
+
+    def check_status(self):
+        try:
+            return self.model.is_resource_ready()
+        except Exception:
+            return False
